@@ -8,10 +8,13 @@ from pathlib import Path
 from shlex import quote
 from sys import stdout
 from time import sleep as time_sleep
-from typing import List, Tuple
+from typing import List, Optional, Tuple
 
+from contracts import contract
 from tqdm import tqdm
 
+DEFAULT_RING_FILENAME = "ring.mp3"
+
 ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath("assets")
 CLOCK_DIR_IN_PROG = ASSET_DIR_IN_PROG / "clock"
 SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / "sound"
@@ -132,7 +135,9 @@ def get_real_json_filename(path: str) -> str:
     return path
 
 
-def get_real_sound_filename(path_: str) -> str:
+def get_real_sound_filename(path_: Optional[str]) -> str:
+    if path_ is None:
+        path_ = DEFAULT_RING_FILENAME
     path = Path(path_).expanduser()
 
     if path.exists():
@@ -165,6 +170,7 @@ def notify(title: str, message: str, cmd_io=None) -> None:
         print(cmd, file=cmd_io)
 
 
+@contract(spend_sec=">=0")
 def notify_all(
     title: str,
     message: str,
